@@ -12,7 +12,7 @@ static void threadMainEntry(LPVOID lpParameter)
     std::filesystem::path modulePath = migi::Platform::getModulePath(reinterpret_cast<void*>(threadMainEntry));
     const std::string migiPathStr = std::filesystem::absolute(modulePath).string();
     const char* argv[] = { migiPathStr.c_str() };
-    start(1, argv, reinterpret_cast<uintptr_t>(lpParameter));
+    migi::start(1, argv, reinterpret_cast<uintptr_t>(lpParameter));
     VirtualFree(lpParameter, 0, MEM_RELEASE);
 }
 
@@ -28,14 +28,14 @@ BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID /*lpReserved*/)
             GetThreadDescription(GetCurrentThread(), &lpThreadDescription);
             if(lpThreadDescription) {
                 WCHAR* lpStrEnd;
-                setExtraParameterPtr(static_cast<uintptr_t>(std::wcstoull(lpThreadDescription, &lpStrEnd, 10)));
+                migi::setExtraParameterPtr(static_cast<uintptr_t>(std::wcstoull(lpThreadDescription, &lpStrEnd, 10)));
             }
             std::thread mainThread(threadMainEntry, hinstDLL);
             mainThread.detach();
             break;
         }
         case DLL_PROCESS_DETACH:
-            detach();
+            migi::detach();
             break;
         case DLL_THREAD_ATTACH:
             break;
