@@ -247,14 +247,22 @@ private:
     }
 
     static PyObject* read_line(Instance* self, PyObject* /*args*/) {
-        return py::Object::toPyObject(self->instance()->readLine());
+        std::string line;
+        {
+            const py::GILScopedRelease release;
+            line = self->instance()->readLine();
+        }
+        return py::Object::toPyObject(line);
     }
 
     static PyObject* write(Instance* self, PyObject* args) {
         const char* arg0;
         if(!PyArg_ParseTuple(args, "s", &arg0))
             Py_RETURN_NONE;
-        self->instance()->write(arg0);
+        {
+            const py::GILScopedRelease release;
+            self->instance()->write(arg0);
+        }
         Py_RETURN_NONE;
     }
 
@@ -533,15 +541,6 @@ static PyObject* migi_get_module_file_path(PyObject* /*self*/, PyObject* /*args*
     return py::Object::toPyObject(get_module_file_path());
 }
 
-static PyObject* migi_find_file(PyObject* /*self*/, PyObject* args)
-{
-    const char* arg0;
-    const char* arg1;
-    if(!PyArg_ParseTuple(args, "ss", &arg0, &arg1))
-        Py_RETURN_NONE;
-    return py::Object::toPyObject(find_file(arg0, arg1));
-}
-
 static PyObject* migi_logd(PyObject* /*self*/, PyObject* args)
 {
     const char* arg0;
@@ -569,6 +568,17 @@ static PyObject* migi_get_module_proc(PyObject* /*self*/, PyObject* args)
     return py::Object::toPyObject(get_module_proc(arg0, arg1));
 }
 
+static PyObject* migi_get_properties(PyObject* /*self*/, PyObject* /*args*/)
+{
+    return py::Object::toPyObject(get_properties());
+}
+
+static PyObject* migi_detach(PyObject* /*self*/, PyObject* /*args*/)
+{
+    detach();
+    Py_RETURN_NONE;
+}
+
 }
 
 
@@ -591,10 +601,11 @@ PyMODINIT_FUNC PyInit__migi(void) {
         {"make_interceptor",  migi::migi_make_interceptor, METH_VARARGS, "make_interceptor"},
         {"start_console",  migi::migi_start_console, METH_VARARGS, "start_console"},
         {"get_module_file_path",  migi::migi_get_module_file_path, METH_VARARGS, "get_module_file_path"},
-        {"find_file",  migi::migi_find_file, METH_VARARGS, "find_file"},
         {"logd",  migi::migi_logd, METH_VARARGS, "logd"},
         {"get_module_addr",  migi::migi_get_module_addr, METH_VARARGS, "get_module_addr"},
         {"get_module_proc",  migi::migi_get_module_proc, METH_VARARGS, "get_module_proc"},
+        {"get_properties",  migi::migi_get_properties, METH_VARARGS, "get_properties"},
+        {"detach",  migi::migi_detach, METH_VARARGS, "detach"},
         {nullptr, nullptr, 0, nullptr}
     };
 
